package com.agri.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.agri.system.domain.SysDtuRemark;

/**
 * dtu设备备注Mapper接口
 * 
 * @author lld
 * @date 2026-01-21
 */
public interface SysDtuRemarkMapper extends BaseMapper<SysDtuRemark>
{
    /**
     * 查询dtu设备备注
     * 
     * @param id dtu设备备注主键
     * @return dtu设备备注
     */
    public SysDtuRemark selectSysDtuRemarkById(Long id);

    /**
     * 查询dtu设备备注列表
     * 
     * @param sysDtuRemark dtu设备备注
     * @return dtu设备备注集合
     */
    public List<SysDtuRemark> selectSysDtuRemarkList(SysDtuRemark sysDtuRemark);

    /**
     * 新增dtu设备备注
     * 
     * @param sysDtuRemark dtu设备备注
     * @return 结果
     */
    public int insertSysDtuRemark(SysDtuRemark sysDtuRemark);

    /**
     * 修改dtu设备备注
     * 
     * @param sysDtuRemark dtu设备备注
     * @return 结果
     */
    public int updateSysDtuRemark(SysDtuRemark sysDtuRemark);

    /**
     * 删除dtu设备备注
     * 
     * @param id dtu设备备注主键
     * @return 结果
     */
    public int deleteSysDtuRemarkById(Long id);

    /**
     * 批量删除dtu设备备注
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysDtuRemarkByIds(Long[] ids);
}
